# Genyal: The cheerful genetic algorithm framework

![http://creativecommons.org/licenses/by/4.0/](https://i.creativecommons.org/l/by/4.0/88x31.png)

This work is licensed under a 
[Creative Commons Attribution 4.0 International License](http://creativecommons.org/licenses/by/4.0/)

**Coming soon**

![](https://tenor.com/view/hamster-cute-animal-gif-19006946)
